@@ -3,6 +3,6 @@ import os, sys
 os.chdir("..")
 sys.path.append(".")
 
-sys.argv.append('-netpyne')
+sys.argv.append("-netpyne")
 
 import Example4
