@@ -5,10 +5,10 @@ from neuromllite.NetworkGenerator import check_to_generate_or_run
 os.chdir("..")
 sys.path.append(".")
 
-sys.argv.append('-jnmlnrn')
+sys.argv.append("-jnmlnrn")
 
 from Example7 import generate
 
 sim, net = generate()
 
-check_to_generate_or_run(sys.argv, sim)
\ No newline at end of file
+check_to_generate_or_run(sys.argv, sim)
